@@ -27,7 +27,8 @@ import hildon
 from hildondesktop import StatusMenuItem
 import subprocess
 
-ACT="/home/maemo/dev/actman/actman/scripts/activity"
+#ACT="/home/maemo/dev/actman/actman/scripts/activity"
+ACT="/usr/bin/activity"
 
 import os
 import sys
@@ -262,7 +263,7 @@ It will be a clone of the current one.""")
 	d.vbox.pack_start(pa)
 
 	l=gtk.Label("""\
-This is ActMan v%s. An activity manager for N900.
+This is ActMan v%s. A desktop activity manager for N900.
 
 An activity is the set of all desktop Widgets, Bookmarks and Shortcuts along with the desktop background.
 
@@ -350,7 +351,7 @@ class actman_applet(StatusMenuItem):
 
     def refreshButton(self):
 	act=self.acts.getCurrentActivity()
-	self.but.set_text("Activity Manager", act)
+	self.but.set_text("Desktop Activity", act)
 
     def eventButClicked(self, obj):
 #	print "clicked"
